//**********************************************************************
// Hippocampus granule cell, simplified/approximate version
// Reference: Holmes WR & Levy WB: Insights into associative
//  long-term potentiation from computational models of NMDA
//  receptor-mediated caclcium influx and intracellular calcium
//  concentrations changes.  J. Neurophysiol. 63, 1148-1168, 1990.
//
//  Implemented by Erik De Schutter
//**********************************************************************

// Control lines start with '*'. Valid control options are 
// *relative 			- relative coords.
// *absolute			- absolute coords.				(default)
// *asymmetric			- use asymmetric compartments	(default)
// *symmetric			- use symmetric compartments
// *spherical			- use spherical compartments
// *cylindrical			- use cylindrical compartments	(default)
// *compt				- select prototype compartment (with children)
//		Do not mix *compt with *spherical/*cylindrical control lines

// #	name	parent		x	y	z	d	c	ch	dens	ch	dens...
// x,y,z,d are in um; c is in nM

*set_global	CM	0.01
*set_global	RM  1.20
*set_global	RA	0.70

*relative
*compt /library/somacomp
soma		none		0	0	0	15.0
*compt /library/symcompartment
apdend1.1 	soma		0	0	20	4.00
apdend1.2	apdend1.1	0	3	10	3.00
apdend1.3	apdend1.1	30	-5	7	3.00
apdend2.1	soma		-2	0	30	2.00
apdend2.2	apdend2.1	-25	0	60	1.50

// to simulate spines we increase membrane area by a factor of 2
*set_global	CM	0.02
*set_global	RM  0.60
dendr1.1	apdend1.2	-30	5	35	2.00
dendr1.2	dendr1.1	-75	0	60	1.50
dendr1.3	dendr1.2	-60	-2	10	1.00
dendr1.4	dendr1.2	-50	2	30	1.00
dendr1.5	dendr1.1	-70	-5	120	1.50
dendr2.1	apdend1.2	-10	2	45	1.50
dendr2.2	dendr2.1	-45	0	80	1.20
dendr2.3	dendr2.2	-50	-8	50	1.00
dendr2.4	dendr2.2	-40	-4	60	1.00
dendr2.5	dendr2.1	5	6	100	1.20
dendr2.6	dendr2.5	-3	4	55	1.00
dendr2.7	dendr2.5	0	0	100	1.00
dendr3.1	apdend1.2	10	-2	30	1.50
dendr3.2	dendr3.1	0	-2	45	1.50
// rest of dendr3 includes all the spines and is specified below
dendr4.1	apdend1.3	10	0	100	1.50
dendr4.2	dendr4.1	0	3	120	1.20
dendr5.1	apdend1.3	70	-6	80	1.50
dendr5.2	dendr5.1	5	2	120	1.00
dendr5.3	dendr5.1	65	4	100	1.20
dendr6.1	apdend2.2	-40	0	35	1.20
dendr7.1	apdend2.2	2	0	80	1.20
dendr7.2	dendr7.1	-50	0	45	1.00
dendr7.3	dendr7.2	-2	0	40	1.00

// Rest of dendr3: includes 7-comp spines on 4-comp dendrite parts
//	with Ca-dynamics, intermingled with ordinary comps.
// Spines are modeled explicitly: no membrane area  scaling!
*set_global	CM	0.01
*set_global	RM  1.20

*compt	/library/basecomp
den02.1		dendr3.2	0	0	0.5	1
den02.2		den02.1		0	0	0.5	1
den02.3		den02.2		0	0	0.5	1
den02.4		den02.3		0	0	0.5	1
*compt	/library/tailcomp
tail02.3	den02.2		0.20 0	0	0.10
tail02.2	tail02.3	0.33 0	0	0.10
tail02.1	tail02.2	0.20 0	0	0.10
*compt	/library/headcomp
head02.4	tail02.1	0.20 0	0	0.55
head02.3	head02.4	0.25 0	0	0.55
*compt	/library/head2comp
head02.2	head02.3	0.05 0	0	0.55
*compt	/library/head1comp
head02.1	head02.2	0.05 0	0	0.55
*compt /library/symcompartment
dendr3.3	den02.4		0	0	0.7	1.00
*compt	/library/basecomp
den03.1		dendr3.3	0	0	0.5	1
den03.2		den03.1		0	0	0.5	1
den03.3		den03.2		0	0	0.5	1
den03.4		den03.3		0	0	0.5	1
*compt	/library/tailcomp
tail03.3	den03.2		0.20 0	0	0.10
tail03.2	tail03.3	0.33 0	0	0.10
tail03.1	tail03.2	0.20 0	0	0.10
*compt	/library/headcomp
head03.4	tail03.1	0.20 0	0	0.55
head03.3	head03.4	0.25 0	0	0.55
*compt	/library/head2comp
head03.2	head03.3	0.05 0	0	0.55
*compt	/library/head1comp
head03.1	head03.2	0.05 0	0	0.55
*compt /library/symcompartment
dendr3.4	den03.4		0	0	0.3	1.00
*compt	/library/basecomp
den04.1		dendr3.4	0	0	0.5	1
den04.2		den04.1		0	0	0.5	1
den04.3		den04.2		0	0	0.5	1
den04.4		den04.3		0	0	0.5	1
*compt	/library/tailcomp
tail04.3	den04.2		0.20 0	0	0.10
tail04.2	tail04.3	0.33 0	0	0.10
tail04.1	tail04.2	0.20 0	0	0.10
*compt	/library/headcomp
head04.4	tail04.1	0.20 0	0	0.55
head04.3	head04.4	0.25 0	0	0.55
*compt	/library/head2comp
head04.2	head04.3	0.05 0	0	0.55
*compt	/library/head1comp
head04.1	head04.2	0.05 0	0	0.55
*compt	/library/basecomp
den05.1		den04.4		0	0	0.5	1
den05.2		den05.1		0	0	0.5	1
den05.3		den05.2		0	0	0.5	1
den05.4		den05.3		0	0	0.5	1
*compt	/library/tailcomp
tail05.3	den05.2		0.20 0	0	0.10
tail05.2	tail05.3	0.33 0	0	0.10
tail05.1	tail05.2	0.20 0	0	0.10
*compt	/library/headcomp
head05.4	tail05.1	0.20 0	0	0.55
head05.3	head05.4	0.25 0	0	0.55
*compt	/library/head2comp
head05.2	head05.3	0.05 0	0	0.55
*compt	/library/head1comp
head05.1	head05.2	0.05 0	0	0.55
*compt /library/symcompartment
dendr3.6	den05.4		0	0	0.4	1.00
*compt	/library/basecomp
den06.1		dendr3.6	0	0	0.5	1
den06.2		den06.1		0	0	0.5	1
den06.3		den06.2		0	0	0.5	1
den06.4		den06.3		0	0	0.5	1
*compt	/library/tailcomp
tail06.3	den06.2		0.20 0	0	0.10
tail06.2	tail06.3	0.33 0	0	0.10
tail06.1	tail06.2	0.20 0	0	0.10
*compt	/library/headcomp
head06.4	tail06.1	0.20 0	0	0.55
head06.3	head06.4	0.25 0	0	0.55
*compt	/library/head2comp
head06.2	head06.3	0.05 0	0	0.55
*compt	/library/head1comp
head06.1	head06.2	0.05 0	0	0.55
*compt /library/symcompartment
dendr3.7	den06.4		0	0	0.6	1.00
*compt	/library/basecomp
den07.1		dendr3.7	0	0	0.5	1
den07.2		den07.1		0	0	0.5	1
den07.3		den07.2		0	0	0.5	1
den07.4		den07.3		0	0	0.5	1
*compt	/library/tailcomp
tail07.3	den07.2		0.20 0	0	0.10
tail07.2	tail07.3	0.33 0	0	0.10
tail07.1	tail07.2	0.20 0	0	0.10
*compt	/library/headcomp
head07.4	tail07.1	0.20 0	0	0.55
head07.3	head07.4	0.25 0	0	0.55
*compt	/library/head2comp
head07.2	head07.3	0.05 0	0	0.55
*compt	/library/head1comp
head07.1	head07.2	0.05 0	0	0.55
*compt /library/symcompartment
dendr3.8	den07.4		0	0	0.5	1.00
*compt	/library/basecomp
den08.1		dendr3.8	0	0	0.5	1
den08.2		den08.1		0	0	0.5	1
den08.3		den08.2		0	0	0.5	1
den08.4		den08.3		0	0	0.5	1
*compt	/library/tailcomp
tail08.3	den08.2		0.20 0	0	0.10
tail08.2	tail08.3	0.33 0	0	0.10
tail08.1	tail08.2	0.20 0	0	0.10
*compt	/library/headcomp
head08.4	tail08.1	0.20 0	0	0.55
head08.3	head08.4	0.25 0	0	0.55
*compt	/library/head2comp
head08.2	head08.3	0.05 0	0	0.55
*compt	/library/head1comp
head08.1	head08.2	0.05 0	0	0.55
*compt /library/symcompartment
dendr3.9	den08.4		0	0	0.5	1.00
*compt	/library/basecomp
den09.1		dendr3.9	0	0	0.5	1
den09.2		den09.1		0	0	0.5	1
den09.3		den09.2		0	0	0.5	1
den09.4		den09.3		0	0	0.5	1
*compt	/library/tailcomp
tail09.3	den09.2		0.20 0	0	0.10
tail09.2	tail09.3	0.33 0	0	0.10
tail09.1	tail09.2	0.20 0	0	0.10
*compt	/library/headcomp
head09.4	tail09.1	0.20 0	0	0.55
head09.3	head09.4	0.25 0	0	0.55
*compt	/library/head2comp
head09.2	head09.3	0.05 0	0	0.55
*compt	/library/head1comp
head09.1	head09.2	0.05 0	0	0.55
*compt /library/symcompartment
dendr3.10	den09.4		0	0	0.3	1.00

*compt	/library/basecomp
den10.1		dendr3.10	0	0	0.5	1
den10.2		den10.1		0	0	0.5	1
den10.3		den10.2		0	0	0.5	1
den10.4		den10.3		0	0	0.5	1
*compt	/library/tailcomp
tail10.3	den10.2		0.20 0	0	0.10
tail10.2	tail10.3	0.33 0	0	0.10
tail10.1	tail10.2	0.20 0	0	0.10
*compt	/library/headcomp
head10.4	tail10.1	0.20 0	0	0.55
head10.3	head10.4	0.25 0	0	0.55
*compt	/library/head2comp
head10.2	head10.3	0.05 0	0	0.55
*compt	/library/head1comp
head10.1	head10.2	0.05 0	0	0.55
*compt /library/symcompartment
dendr3.11	den10.4		0	0	0.4	1.00
*compt	/library/basecomp
den11.1		dendr3.11	0	0	0.5	1
den11.2		den11.1		0	0	0.5	1
den11.3		den11.2		0	0	0.5	1
den11.4		den11.3		0	0	0.5	1
*compt	/library/tailcomp
tail11.3	den11.2		0.20 0	0	0.10
tail11.2	tail11.3	0.33 0	0	0.10
tail11.1	tail11.2	0.20 0	0	0.10
*compt	/library/headcomp
head11.4	tail11.1	0.20 0	0	0.55
head11.3	head11.4	0.25 0	0	0.55
*compt	/library/head2comp
head11.2	head11.3	0.05 0	0	0.55
*compt	/library/head1comp
head11.1	head11.2	0.05 0	0	0.55
*compt /library/symcompartment
dendr3.12	den11.4		0	0	0.6	1.00
*compt	/library/basecomp
den12.1		dendr3.12	0	0	0.5	1
den12.2		den12.1		0	0	0.5	1
den12.3		den12.2		0	0	0.5	1
den12.4		den12.3		0	0	0.5	1
*compt	/library/tailcomp
tail12.3	den12.2		0.20 0	0	0.10
tail12.2	tail12.3	0.33 0	0	0.10
tail12.1	tail12.2	0.20 0	0	0.10
*compt	/library/headcomp
head12.4	tail12.1	0.20 0	0	0.55
head12.3	head12.4	0.25 0	0	0.55
*compt	/library/head2comp
head12.2	head12.3	0.05 0	0	0.55
*compt	/library/head1comp
head12.1	head12.2	0.05 0	0	0.55
*compt /library/symcompartment
dendr3.13	den12.4		0	0	0.8	1.00
*compt	/library/basecomp
den13.1		dendr3.13	0	0	0.5	1
den13.2		den13.1		0	0	0.5	1
den13.3		den13.2		0	0	0.5	1
den13.4		den13.3		0	0	0.5	1
*compt	/library/tailcomp
tail13.3	den13.2		0.20 0	0	0.10
tail13.2	tail13.3	0.33 0	0	0.10
tail13.1	tail13.2	0.20 0	0	0.10
*compt	/library/headcomp
head13.4	tail13.1	0.20 0	0	0.55
head13.3	head13.4	0.25 0	0	0.55
*compt	/library/head2comp
head13.2	head13.3	0.05 0	0	0.55
*compt	/library/head1comp
head13.1	head13.2	0.05 0	0	0.55
*compt /library/symcompartment
dendr3.14	den13.4		0	0	0.5	1.00
*compt	/library/basecomp
den14.1		dendr3.14	0	0	0.5	1
den14.2		den14.1		0	0	0.5	1
den14.3		den14.2		0	0	0.5	1
den14.4		den14.3		0	0	0.5	1
*compt	/library/tailcomp
tail14.3	den14.2		0.20 0	0	0.10
tail14.2	tail14.3	0.33 0	0	0.10
tail14.1	tail14.2	0.20 0	0	0.10
*compt	/library/headcomp
head14.4	tail14.1	0.20 0	0	0.55
head14.3	head14.4	0.25 0	0	0.55
*compt	/library/head2comp
head14.2	head14.3	0.05 0	0	0.55
*compt	/library/head1comp
head14.1	head14.2	0.05 0	0	0.55
*compt	/library/basecomp
den15.1		den14.4		0	0	0.5	1
den15.2		den15.1		0	0	0.5	1
den15.3		den15.2		0	0	0.5	1
den15.4		den15.3		0	0	0.5	1
*compt	/library/tailcomp
tail15.3	den15.2		0.20 0	0	0.10
tail15.2	tail15.3	0.33 0	0	0.10
tail15.1	tail15.2	0.20 0	0	0.10
*compt	/library/headcomp
head15.4	tail15.1	0.20 0	0	0.55
head15.3	head15.4	0.25 0	0	0.55
*compt	/library/head2comp
head15.2	head15.3	0.05 0	0	0.55
*compt	/library/head1comp
head15.1	head15.2	0.05 0	0	0.55
*compt	/library/basecomp
den16.1		den15.4		0	0	0.5	1
den16.2		den16.1		0	0	0.5	1
den16.3		den16.2		0	0	0.5	1
den16.4		den16.3		0	0	0.5	1
*compt	/library/tailcomp
tail16.3	den16.2		0.20 0	0	0.10
tail16.2	tail16.3	0.33 0	0	0.10
tail16.1	tail16.2	0.20 0	0	0.10
*compt	/library/headcomp
head16.4	tail16.1	0.20 0	0	0.55
head16.3	head16.4	0.25 0	0	0.55
*compt	/library/head2comp
head16.2	head16.3	0.05 0	0	0.55
*compt	/library/head1comp
head16.1	head16.2	0.05 0	0	0.55
*compt /library/symcompartment
dendr3.17	den16.4		0	0	0.4	1.00
*compt	/library/basecomp
den17.1		dendr3.17	0	0	0.5	1
den17.2		den17.1		0	0	0.5	1
den17.3		den17.2		0	0	0.5	1
den17.4		den17.3		0	0	0.5	1
*compt	/library/tailcomp
tail17.3	den17.2		0.20 0	0	0.10
tail17.2	tail17.3	0.33 0	0	0.10
tail17.1	tail17.2	0.20 0	0	0.10
*compt	/library/headcomp
head17.4	tail17.1	0.20 0	0	0.55
head17.3	head17.4	0.25 0	0	0.55
*compt	/library/head2comp
head17.2	head17.3	0.05 0	0	0.55
*compt	/library/head1comp
head17.1	head17.2	0.05 0	0	0.55
*compt /library/symcompartment
dendr3.18	den17.4		0	0	0.6	1.00
*compt	/library/basecomp
den18.1		dendr3.18	0	0	0.5	1
den18.2		den18.1		0	0	0.5	1
den18.3		den18.2		0	0	0.5	1
den18.4		den18.3		0	0	0.5	1
*compt	/library/tailcomp
tail18.3	den18.2		0.20 0	0	0.10
tail18.2	tail18.3	0.33 0	0	0.10
tail18.1	tail18.2	0.20 0	0	0.10
*compt	/library/headcomp
head18.4	tail18.1	0.20 0	0	0.55
head18.3	head18.4	0.25 0	0	0.55
*compt	/library/head2comp
head18.2	head18.3	0.05 0	0	0.55
*compt	/library/head1comp
head18.1	head18.2	0.05 0	0	0.55
*compt /library/symcompartment
dendr3.19	den18.4		0	0	0.5	1.00
*compt	/library/basecomp
den19.1		dendr3.19	0	0	0.5	1
den19.2		den19.1		0	0	0.5	1
den19.3		den19.2		0	0	0.5	1
den19.4		den19.3		0	0	0.5	1
*compt	/library/tailcomp
tail19.3	den19.2		0.20 0	0	0.10
tail19.2	tail19.3	0.33 0	0	0.10
tail19.1	tail19.2	0.20 0	0	0.10
*compt	/library/headcomp
head19.4	tail19.1	0.20 0	0	0.55
head19.3	head19.4	0.25 0	0	0.55
*compt	/library/head2comp
head19.2	head19.3	0.05 0	0	0.55
*compt	/library/head1comp
head19.1	head19.2	0.05 0	0	0.55
*compt /library/symcompartment
dendr3.20	den19.4		0	0	0.7	1.00

*compt	/library/basecomp
den20.1		dendr3.20	0	0	0.5	1
den20.2		den20.1		0	0	0.5	1
den20.3		den20.2		0	0	0.5	1
den20.4		den20.3		0	0	0.5	1
*compt	/library/tailcomp
tail20.3	den20.2		0.20 0	0	0.10
tail20.2	tail20.3	0.33 0	0	0.10
tail20.1	tail20.2	0.20 0	0	0.10
*compt	/library/headcomp
head20.4	tail20.1	0.20 0	0	0.55
head20.3	head20.4	0.25 0	0	0.55
*compt	/library/head2comp
head20.2	head20.3	0.05 0	0	0.55
*compt	/library/head1comp
head20.1	head20.2	0.05 0	0	0.55
*compt /library/symcompartment
dendr3.21	den20.4		0	0	0.4	1.00
*compt	/library/basecomp
den21.1		dendr3.21	0	0	0.5	1
den21.2		den21.1		0	0	0.5	1
den21.3		den21.2		0	0	0.5	1
den21.4		den21.3		0	0	0.5	1
*compt	/library/tailcomp
tail21.3	den21.2		0.20 0	0	0.10
tail21.2	tail21.3	0.33 0	0	0.10
tail21.1	tail21.2	0.20 0	0	0.10
*compt	/library/headcomp
head21.4	tail21.1	0.20 0	0	0.55
head21.3	head21.4	0.25 0	0	0.55
*compt	/library/head2comp
head21.2	head21.3	0.05 0	0	0.55
*compt	/library/head1comp
head21.1	head21.2	0.05 0	0	0.55
*compt /library/symcompartment
dendr3.22	den21.4		0	0	0.6	1.00
*compt	/library/basecomp
den22.1		dendr3.22	0	0	0.5	1
den22.2		den22.1		0	0	0.5	1
den22.3		den22.2		0	0	0.5	1
den22.4		den22.3		0	0	0.5	1
*compt	/library/tailcomp
tail22.3	den22.2		0.20 0	0	0.10
tail22.2	tail22.3	0.33 0	0	0.10
tail22.1	tail22.2	0.20 0	0	0.10
*compt	/library/headcomp
head22.4	tail22.1	0.20 0	0	0.55
head22.3	head22.4	0.25 0	0	0.55
*compt	/library/head2comp
head22.2	head22.3	0.05 0	0	0.55
*compt	/library/head1comp
head22.1	head22.2	0.05 0	0	0.55
*compt /library/symcompartment
dendr3.23	den22.4		0	0	0.9	1.00
*compt	/library/basecomp
den23.1		dendr3.23	0	0	0.5	1
den23.2		den23.1		0	0	0.5	1
den23.3		den23.2		0	0	0.5	1
den23.4		den23.3		0	0	0.5	1
*compt	/library/tailcomp
tail23.3	den23.2		0.20 0	0	0.10
tail23.2	tail23.3	0.33 0	0	0.10
tail23.1	tail23.2	0.20 0	0	0.10
*compt	/library/headcomp
head23.4	tail23.1	0.20 0	0	0.55
head23.3	head23.4	0.25 0	0	0.55
*compt	/library/head2comp
head23.2	head23.3	0.05 0	0	0.55
*compt	/library/head1comp
head23.1	head23.2	0.05 0	0	0.55
*compt /library/symcompartment
dendr3.24	den23.4		0	0	0.8	1.00
*compt	/library/basecomp
den24.1		dendr3.24	0	0	0.5	1
den24.2		den24.1		0	0	0.5	1
den24.3		den24.2		0	0	0.5	1
den24.4		den24.3		0	0	0.5	1
*compt	/library/tailcomp
tail24.3	den24.2		0.20 0	0	0.10
tail24.2	tail24.3	0.33 0	0	0.10
tail24.1	tail24.2	0.20 0	0	0.10
*compt	/library/headcomp
head24.4	tail24.1	0.20 0	0	0.55
head24.3	head24.4	0.25 0	0	0.55
*compt	/library/head2comp
head24.2	head24.3	0.05 0	0	0.55
*compt	/library/head1comp
head24.1	head24.2	0.05 0	0	0.55
*compt	/library/basecomp
den25.1		den24.4		0	0	0.5	1
den25.2		den25.1		0	0	0.5	1
den25.3		den25.2		0	0	0.5	1
den25.4		den25.3		0	0	0.5	1
*compt	/library/tailcomp
tail25.3	den25.2		0.20 0	0	0.10
tail25.2	tail25.3	0.33 0	0	0.10
tail25.1	tail25.2	0.20 0	0	0.10
*compt	/library/headcomp
head25.4	tail25.1	0.20 0	0	0.55
head25.3	head25.4	0.25 0	0	0.55
*compt	/library/head2comp
head25.2	head25.3	0.05 0	0	0.55
*compt	/library/head1comp
head25.1	head25.2	0.05 0	0	0.55
*compt	/library/basecomp
den26.1		den25.4		0	0	0.5	1
den26.2		den26.1		0	0	0.5	1
den26.3		den26.2		0	0	0.5	1
den26.4		den26.3		0	0	0.5	1
*compt	/library/tailcomp
tail26.3	den26.2		0.20 0	0	0.10
tail26.2	tail26.3	0.33 0	0	0.10
tail26.1	tail26.2	0.20 0	0	0.10
*compt	/library/headcomp
head26.4	tail26.1	0.20 0	0	0.55
head26.3	head26.4	0.25 0	0	0.55
*compt	/library/head2comp
head26.2	head26.3	0.05 0	0	0.55
*compt	/library/head1comp
head26.1	head26.2	0.05 0	0	0.55
*compt /library/symcompartment
dendr3.27	den26.4		0	0	0.6	1.00
*compt	/library/basecomp
den27.1		dendr3.27	0	0	0.5	1
den27.2		den27.1		0	0	0.5	1
den27.3		den27.2		0	0	0.5	1
den27.4		den27.3		0	0	0.5	1
*compt	/library/tailcomp
tail27.3	den27.2		0.20 0	0	0.10
tail27.2	tail27.3	0.33 0	0	0.10
tail27.1	tail27.2	0.20 0	0	0.10
*compt	/library/headcomp
head27.4	tail27.1	0.20 0	0	0.55
head27.3	head27.4	0.25 0	0	0.55
*compt	/library/head2comp
head27.2	head27.3	0.05 0	0	0.55
*compt	/library/head1comp
head27.1	head27.2	0.05 0	0	0.55
*compt /library/symcompartment
dendr3.28	den27.4		0	0	0.8	1.00
*compt	/library/basecomp
den28.1		dendr3.28	0	0	0.5	1
den28.2		den28.1		0	0	0.5	1
den28.3		den28.2		0	0	0.5	1
den28.4		den28.3		0	0	0.5	1
*compt	/library/tailcomp
tail28.3	den28.2		0.20 0	0	0.10
tail28.2	tail28.3	0.33 0	0	0.10
tail28.1	tail28.2	0.20 0	0	0.10
*compt	/library/headcomp
head28.4	tail28.1	0.20 0	0	0.55
head28.3	head28.4	0.25 0	0	0.55
*compt	/library/head2comp
head28.2	head28.3	0.05 0	0	0.55
*compt	/library/head1comp
head28.1	head28.2	0.05 0	0	0.55
*compt /library/symcompartment
dendr3.29	den28.4		0	0	0.5	1.00
*compt	/library/basecomp
den29.1		dendr3.29	0	0	0.5	1
den29.2		den29.1		0	0	0.5	1
den29.3		den29.2		0	0	0.5	1
den29.4		den29.3		0	0	0.5	1
*compt	/library/tailcomp
tail29.3	den29.2		0.20 0	0	0.10
tail29.2	tail29.3	0.33 0	0	0.10
tail29.1	tail29.2	0.20 0	0	0.10
*compt	/library/headcomp
head29.4	tail29.1	0.20 0	0	0.55
head29.3	head29.4	0.25 0	0	0.55
*compt	/library/head2comp
head29.2	head29.3	0.05 0	0	0.55
*compt	/library/head1comp
head29.1	head29.2	0.05 0	0	0.55
*compt /library/symcompartment
dendr3.30	den29.4		0	0	0.5	1.00

*compt	/library/basecomp
den30.1		dendr3.30	0	0	0.5	1
den30.2		den30.1		0	0	0.5	1
den30.3		den30.2		0	0	0.5	1
den30.4		den30.3		0	0	0.5	1
*compt	/library/tailcomp
tail30.3	den30.2		0.20 0	0	0.10
tail30.2	tail30.3	0.33 0	0	0.10
tail30.1	tail30.2	0.20 0	0	0.10
*compt	/library/headcomp
head30.4	tail30.1	0.20 0	0	0.55
head30.3	head30.4	0.25 0	0	0.55
*compt	/library/head2comp
head30.2	head30.3	0.05 0	0	0.55
*compt	/library/head1comp
head30.1	head30.2	0.05 0	0	0.55
dendr3.31	den30.4		0	0	0.4	1.00
*compt	/library/basecomp
den31.1		dendr3.31	0	0	0.5	1
den31.2		den31.1		0	0	0.5	1
den31.3		den31.2		0	0	0.5	1
den31.4		den31.3		0	0	0.5	1
*compt	/library/tailcomp
tail31.3	den31.2		0.20 0	0	0.10
tail31.2	tail31.3	0.33 0	0	0.10
tail31.1	tail31.2	0.20 0	0	0.10
*compt	/library/headcomp
head31.4	tail31.1	0.20 0	0	0.55
head31.3	head31.4	0.25 0	0	0.55
*compt	/library/head2comp
head31.2	head31.3	0.05 0	0	0.55
*compt	/library/head1comp
head31.1	head31.2	0.05 0	0	0.55
*compt	/library/basecomp
den32.1		den31.4		0	0	0.5	1
den32.2		den32.1		0	0	0.5	1
den32.3		den32.2		0	0	0.5	1
den32.4		den32.3		0	0	0.5	1
*compt	/library/tailcomp
tail32.3	den32.2		0.20 0	0	0.10
tail32.2	tail32.3	0.33 0	0	0.10
tail32.1	tail32.2	0.20 0	0	0.10
*compt	/library/headcomp
head32.4	tail32.1	0.20 0	0	0.55
head32.3	head32.4	0.25 0	0	0.55
*compt	/library/head2comp
head32.2	head32.3	0.05 0	0	0.55
*compt	/library/head1comp
head32.1	head32.2	0.05 0	0	0.55
*compt /library/symcompartment
dendr3.33	den32.4		0	0	0.6	1.00
*compt	/library/basecomp
den33.1		dendr3.33	0	0	0.5	1
den33.2		den33.1		0	0	0.5	1
den33.3		den33.2		0	0	0.5	1
den33.4		den33.3		0	0	0.5	1
*compt	/library/tailcomp
tail33.3	den33.2		0.20 0	0	0.10
tail33.2	tail33.3	0.33 0	0	0.10
tail33.1	tail33.2	0.20 0	0	0.10
*compt	/library/headcomp
head33.4	tail33.1	0.20 0	0	0.55
head33.3	head33.4	0.25 0	0	0.55
*compt	/library/head2comp
head33.2	head33.3	0.05 0	0	0.55
*compt	/library/head1comp
head33.1	head33.2	0.05 0	0	0.55
*compt /library/symcompartment
dendr3.34	den33.4		0	0	0.7	1.00
*compt	/library/basecomp
den34.1		dendr3.34	0	0	0.5	1
den34.2		den34.1		0	0	0.5	1
den34.3		den34.2		0	0	0.5	1
den34.4		den34.3		0	0	0.5	1
*compt	/library/tailcomp
tail34.3	den34.2		0.20 0	0	0.10
tail34.2	tail34.3	0.33 0	0	0.10
tail34.1	tail34.2	0.20 0	0	0.10
*compt	/library/headcomp
head34.4	tail34.1	0.20 0	0	0.55
head34.3	head34.4	0.25 0	0	0.55
*compt	/library/head2comp
head34.2	head34.3	0.05 0	0	0.55
*compt	/library/head1comp
head34.1	head34.2	0.05 0	0	0.55
*compt	/library/basecomp
den35.1		den34.4		0	0	0.5	1
den35.2		den35.1		0	0	0.5	1
den35.3		den35.2		0	0	0.5	1
den35.4		den35.3		0	0	0.5	1
*compt	/library/tailcomp
tail35.3	den35.2		0.20 0	0	0.10
tail35.2	tail35.3	0.33 0	0	0.10
tail35.1	tail35.2	0.20 0	0	0.10
*compt	/library/headcomp
head35.4	tail35.1	0.20 0	0	0.55
head35.3	head35.4	0.25 0	0	0.55
*compt	/library/head2comp
head35.2	head35.3	0.05 0	0	0.55
*compt	/library/head1comp
head35.1	head35.2	0.05 0	0	0.55
*compt /library/symcompartment
dendr3.36	den35.4		0	0	0.4	1.00
*compt	/library/basecomp
den36.1		dendr3.36	0	0	0.5	1
den36.2		den36.1		0	0	0.5	1
den36.3		den36.2		0	0	0.5	1
den36.4		den36.3		0	0	0.5	1
*compt	/library/tailcomp
tail36.3	den36.2		0.20 0	0	0.10
tail36.2	tail36.3	0.33 0	0	0.10
tail36.1	tail36.2	0.20 0	0	0.10
*compt	/library/headcomp
head36.4	tail36.1	0.20 0	0	0.55
head36.3	head36.4	0.25 0	0	0.55
*compt	/library/head2comp
head36.2	head36.3	0.05 0	0	0.55
*compt	/library/head1comp
head36.1	head36.2	0.05 0	0	0.55
*compt /library/symcompartment
dendr3.37	den36.4		0	0	0.5	1.00
*compt	/library/basecomp
den37.1		dendr3.37	0	0	0.5	1
den37.2		den37.1		0	0	0.5	1
den37.3		den37.2		0	0	0.5	1
den37.4		den37.3		0	0	0.5	1
*compt	/library/tailcomp
tail37.3	den37.2		0.20 0	0	0.10
tail37.2	tail37.3	0.33 0	0	0.10
tail37.1	tail37.2	0.20 0	0	0.10
*compt	/library/headcomp
head37.4	tail37.1	0.20 0	0	0.55
head37.3	head37.4	0.25 0	0	0.55
*compt	/library/head2comp
head37.2	head37.3	0.05 0	0	0.55
*compt	/library/head1comp
head37.1	head37.2	0.05 0	0	0.55
*compt /library/symcompartment
dendr3.38	den37.4		0	0	0.6	1.00
*compt	/library/basecomp
den38.1		dendr3.38	0	0	0.5	1
den38.2		den38.1		0	0	0.5	1
den38.3		den38.2		0	0	0.5	1
den38.4		den38.3		0	0	0.5	1
*compt	/library/tailcomp
tail38.3	den38.2		0.20 0	0	0.10
tail38.2	tail38.3	0.33 0	0	0.10
tail38.1	tail38.2	0.20 0	0	0.10
*compt	/library/headcomp
head38.4	tail38.1	0.20 0	0	0.55
head38.3	head38.4	0.25 0	0	0.55
*compt	/library/head2comp
head38.2	head38.3	0.05 0	0	0.55
*compt	/library/head1comp
head38.1	head38.2	0.05 0	0	0.55
*compt /library/symcompartment
dendr3.39	den38.4		0	0	0.8	1.00
*compt	/library/basecomp
den39.1		dendr3.39	0	0	0.5	1
den39.2		den39.1		0	0	0.5	1
den39.3		den39.2		0	0	0.5	1
den39.4		den39.3		0	0	0.5	1
*compt	/library/tailcomp
tail39.3	den39.2		0.20 0	0	0.10
tail39.2	tail39.3	0.33 0	0	0.10
tail39.1	tail39.2	0.20 0	0	0.10
*compt	/library/headcomp
head39.4	tail39.1	0.20 0	0	0.55
head39.3	head39.4	0.25 0	0	0.55
*compt	/library/head2comp
head39.2	head39.3	0.05 0	0	0.55
*compt	/library/head1comp
head39.1	head39.2	0.05 0	0	0.55
*compt /library/symcompartment
dendr3.40	den39.4		0	0	0.3	1.00

*compt	/library/basecomp
den40.1		dendr3.40	0	0	0.5	1
den40.2		den40.1		0	0	0.5	1
den40.3		den40.2		0	0	0.5	1
den40.4		den40.3		0	0	0.5	1
*compt	/library/tailcomp
tail40.3	den40.2		0.20 0	0	0.10
tail40.2	tail40.3	0.33 0	0	0.10
tail40.1	tail40.2	0.20 0	0	0.10
*compt	/library/headcomp
head40.4	tail40.1	0.20 0	0	0.55
head40.3	head40.4	0.25 0	0	0.55
*compt	/library/head2comp
head40.2	head40.3	0.05 0	0	0.55
*compt	/library/head1comp
head40.1	head40.2	0.05 0	0	0.55
*compt /library/symcompartment
dendr3.41	den40.4		0	0	0.6	1.00
*compt	/library/basecomp
den41.1		dendr3.41	0	0	0.5	1
den41.2		den41.1		0	0	0.5	1
den41.3		den41.2		0	0	0.5	1
den41.4		den41.3		0	0	0.5	1
*compt	/library/tailcomp
tail41.3	den41.2		0.20 0	0	0.10
tail41.2	tail41.3	0.33 0	0	0.10
tail41.1	tail41.2	0.20 0	0	0.10
*compt	/library/headcomp
head41.4	tail41.1	0.20 0	0	0.55
head41.3	head41.4	0.25 0	0	0.55
*compt	/library/head2comp
head41.2	head41.3	0.05 0	0	0.55
*compt	/library/head1comp
head41.1	head41.2	0.05 0	0	0.55
*compt /library/symcompartment
dendr3.42	den41.4		0	0	0.3	1.00
*compt	/library/basecomp
den42.1		dendr3.42	0	0	0.5	1
den42.2		den42.1		0	0	0.5	1
den42.3		den42.2		0	0	0.5	1
den42.4		den42.3		0	0	0.5	1
*compt	/library/tailcomp
tail42.3	den42.2		0.20 0	0	0.10
tail42.2	tail42.3	0.33 0	0	0.10
tail42.1	tail42.2	0.20 0	0	0.10
*compt	/library/headcomp
head42.4	tail42.1	0.20 0	0	0.55
head42.3	head42.4	0.25 0	0	0.55
*compt	/library/head2comp
head42.2	head42.3	0.05 0	0	0.55
*compt	/library/head1comp
head42.1	head42.2	0.05 0	0	0.55
*compt /library/symcompartment
dendr3.43	den42.4		0	0	0.6	1.00
*compt	/library/basecomp
den43.1		dendr3.43	0	0	0.5	1
den43.2		den43.1		0	0	0.5	1
den43.3		den43.2		0	0	0.5	1
den43.4		den43.3		0	0	0.5	1
*compt	/library/tailcomp
tail43.3	den43.2		0.20 0	0	0.10
tail43.2	tail43.3	0.33 0	0	0.10
tail43.1	tail43.2	0.20 0	0	0.10
*compt	/library/headcomp
head43.4	tail43.1	0.20 0	0	0.55
head43.3	head43.4	0.25 0	0	0.55
*compt	/library/head2comp
head43.2	head43.3	0.05 0	0	0.55
*compt	/library/head1comp
head43.1	head43.2	0.05 0	0	0.55
*compt /library/symcompartment
dendr3.44	den43.4		0	0	0.5	1.00
*compt	/library/basecomp
den44.1		dendr3.44	0	0	0.5	1
den44.2		den44.1		0	0	0.5	1
den44.3		den44.2		0	0	0.5	1
den44.4		den44.3		0	0	0.5	1
*compt	/library/tailcomp
tail44.3	den44.2		0.20 0	0	0.10
tail44.2	tail44.3	0.33 0	0	0.10
tail44.1	tail44.2	0.20 0	0	0.10
*compt	/library/headcomp
head44.4	tail44.1	0.20 0	0	0.55
head44.3	head44.4	0.25 0	0	0.55
*compt	/library/head2comp
head44.2	head44.3	0.05 0	0	0.55
*compt	/library/head1comp
head44.1	head44.2	0.05 0	0	0.55
*compt /library/symcompartment
dendr3.45	den44.4		0	0	0.8	1.00
*compt	/library/basecomp
den45.1		dendr3.45	0	0	0.5	1
den45.2		den45.1		0	0	0.5	1
den45.3		den45.2		0	0	0.5	1
den45.4		den45.3		0	0	0.5	1
*compt	/library/tailcomp
tail45.3	den45.2		0.20 0	0	0.10
tail45.2	tail45.3	0.33 0	0	0.10
tail45.1	tail45.2	0.20 0	0	0.10
*compt	/library/headcomp
head45.4	tail45.1	0.20 0	0	0.55
head45.3	head45.4	0.25 0	0	0.55
*compt	/library/head2comp
head45.2	head45.3	0.05 0	0	0.55
*compt	/library/head1comp
head45.1	head45.2	0.05 0	0	0.55
*compt	/library/basecomp
den46.1		den45.4		0	0	0.5	1
den46.2		den46.1		0	0	0.5	1
den46.3		den46.2		0	0	0.5	1
den46.4		den46.3		0	0	0.5	1
*compt	/library/tailcomp
tail46.3	den46.2		0.20 0	0	0.10
tail46.2	tail46.3	0.33 0	0	0.10
tail46.1	tail46.2	0.20 0	0	0.10
*compt	/library/headcomp
head46.4	tail46.1	0.20 0	0	0.55
head46.3	head46.4	0.25 0	0	0.55
*compt	/library/head2comp
head46.2	head46.3	0.05 0	0	0.55
*compt	/library/head1comp
head46.1	head46.2	0.05 0	0	0.55
*compt /library/symcompartment
dendr3.47	den46.4		0	0	0.7	1.00
*compt	/library/basecomp
den47.1		dendr3.47	0	0	0.5	1
den47.2		den47.1		0	0	0.5	1
den47.3		den47.2		0	0	0.5	1
den47.4		den47.3		0	0	0.5	1
*compt	/library/tailcomp
tail47.3	den47.2		0.20 0	0	0.10
tail47.2	tail47.3	0.33 0	0	0.10
tail47.1	tail47.2	0.20 0	0	0.10
*compt	/library/headcomp
head47.4	tail47.1	0.20 0	0	0.55
head47.3	head47.4	0.25 0	0	0.55
*compt	/library/head2comp
head47.2	head47.3	0.05 0	0	0.55
*compt	/library/head1comp
head47.1	head47.2	0.05 0	0	0.55
*compt /library/symcompartment
dendr3.48	den47.4		0	0	0.7	1.00
*compt	/library/basecomp
den48.1		dendr3.48	0	0	0.5	1
den48.2		den48.1		0	0	0.5	1
den48.3		den48.2		0	0	0.5	1
den48.4		den48.3		0	0	0.5	1
*compt	/library/tailcomp
tail48.3	den48.2		0.20 0	0	0.10
tail48.2	tail48.3	0.33 0	0	0.10
tail48.1	tail48.2	0.20 0	0	0.10
*compt	/library/headcomp
head48.4	tail48.1	0.20 0	0	0.55
head48.3	head48.4	0.25 0	0	0.55
*compt	/library/head2comp
head48.2	head48.3	0.05 0	0	0.55
*compt	/library/head1comp
head48.1	head48.2	0.05 0	0	0.55
*compt	/library/basecomp
den49.1		den48.4		0	0	0.5	1
den49.2		den49.1		0	0	0.5	1
den49.3		den49.2		0	0	0.5	1
den49.4		den49.3		0	0	0.5	1
*compt	/library/tailcomp
tail49.3	den49.2		0.20 0	0	0.10
tail49.2	tail49.3	0.33 0	0	0.10
tail49.1	tail49.2	0.20 0	0	0.10
*compt	/library/headcomp
head49.4	tail49.1	0.20 0	0	0.55
head49.3	head49.4	0.25 0	0	0.55
*compt	/library/head2comp
head49.2	head49.3	0.05 0	0	0.55
*compt	/library/head1comp
head49.1	head49.2	0.05 0	0	0.55
*compt /library/symcompartment
dendr3.50	den49.4		5	0	30	0.80
dendr3.50b	dendr3.50	30	0	60	0.80

//second branch of dendrite 3.2 with spines
*compt	/library/basecomp
dendr3.2b	dendr3.2	-5	0	1	0.80
den50.1		dendr3.2b	0	0	0.5	1
den50.2		den50.1		0	0	0.5	1
den50.3		den50.2		0	0	0.5	1
den50.4		den50.3		0	0	0.5	1
*compt	/library/tailcomp
tail50.3	den50.2		0.20 0	0	0.10
tail50.2	tail50.3	0.33 0	0	0.10
tail50.1	tail50.2	0.20 0	0	0.10
*compt	/library/headcomp
head50.4	tail50.1	0.20 0	0	0.55
head50.3	head50.4	0.25 0	0	0.55
*compt	/library/head2comp
head50.2	head50.3	0.05 0	0	0.55
*compt	/library/head1comp
head50.1	head50.2	0.05 0	0	0.55
*compt /library/symcompartment
dendr3.51	den50.4		0	0	0.4	1.00
*compt	/library/basecomp
den51.1		dendr3.51	0	0	0.5	1
den51.2		den51.1		0	0	0.5	1
den51.3		den51.2		0	0	0.5	1
den51.4		den51.3		0	0	0.5	1
*compt	/library/tailcomp
tail51.3	den51.2		0.20 0	0	0.10
tail51.2	tail51.3	0.33 0	0	0.10
tail51.1	tail51.2	0.20 0	0	0.10
*compt	/library/headcomp
head51.4	tail51.1	0.20 0	0	0.55
head51.3	head51.4	0.25 0	0	0.55
*compt	/library/head2comp
head51.2	head51.3	0.05 0	0	0.55
*compt	/library/head1comp
head51.1	head51.2	0.05 0	0	0.55
*compt /library/symcompartment
dendr3.52	den51.4		0	0	0.5	1.00
*compt	/library/basecomp
den52.1		dendr3.52	0	0	0.5	1
den52.2		den52.1		0	0	0.5	1
den52.3		den52.2		0	0	0.5	1
den52.4		den52.3		0	0	0.5	1
*compt	/library/tailcomp
tail52.3	den52.2		0.20 0	0	0.10
tail52.2	tail52.3	0.33 0	0	0.10
tail52.1	tail52.2	0.20 0	0	0.10
*compt	/library/headcomp
head52.4	tail52.1	0.20 0	0	0.55
head52.3	head52.4	0.25 0	0	0.55
*compt	/library/head2comp
head52.2	head52.3	0.05 0	0	0.55
*compt	/library/head1comp
head52.1	head52.2	0.05 0	0	0.55
*compt /library/symcompartment
dendr3.53	den52.4		0	0	0.5	1.00
*compt	/library/basecomp
den53.1		dendr3.53	0	0	0.5	1
den53.2		den53.1		0	0	0.5	1
den53.3		den53.2		0	0	0.5	1
den53.4		den53.3		0	0	0.5	1
*compt	/library/tailcomp
tail53.3	den53.2		0.20 0	0	0.10
tail53.2	tail53.3	0.33 0	0	0.10
tail53.1	tail53.2	0.20 0	0	0.10
*compt	/library/headcomp
head53.4	tail53.1	0.20 0	0	0.55
head53.3	head53.4	0.25 0	0	0.55
*compt	/library/head2comp
head53.2	head53.3	0.05 0	0	0.55
*compt	/library/head1comp
head53.1	head53.2	0.05 0	0	0.55
*compt	/library/basecomp
den54.1		den53.4		0	0	0.5	1
den54.2		den54.1		0	0	0.5	1
den54.3		den54.2		0	0	0.5	1
den54.4		den54.3		0	0	0.5	1
*compt	/library/tailcomp
tail54.3	den54.2		0.20 0	0	0.10
tail54.2	tail54.3	0.33 0	0	0.10
tail54.1	tail54.2	0.20 0	0	0.10
*compt	/library/headcomp
head54.4	tail54.1	0.20 0	0	0.55
head54.3	head54.4	0.25 0	0	0.55
*compt	/library/head2comp
head54.2	head54.3	0.05 0	0	0.55
*compt	/library/head1comp
head54.1	head54.2	0.05 0	0	0.55
*compt /library/symcompartment
dendr3.55	den54.4		0	0	0.5	1.00
*compt	/library/basecomp
den55.1		dendr3.55	0	0	0.5	1
den55.2		den55.1		0	0	0.5	1
den55.3		den55.2		0	0	0.5	1
den55.4		den55.3		0	0	0.5	1
*compt	/library/tailcomp
tail55.3	den55.2		0.20 0	0	0.10
tail55.2	tail55.3	0.33 0	0	0.10
tail55.1	tail55.2	0.20 0	0	0.10
*compt	/library/headcomp
head55.4	tail55.1	0.20 0	0	0.55
head55.3	head55.4	0.25 0	0	0.55
*compt	/library/head2comp
head55.2	head55.3	0.05 0	0	0.55
*compt	/library/head1comp
head55.1	head55.2	0.05 0	0	0.55
*compt /library/symcompartment
dendr3.56	den55.4		0	0	0.4	1.00
*compt	/library/basecomp
den56.1		dendr3.56	0	0	0.5	1
den56.2		den56.1		0	0	0.5	1
den56.3		den56.2		0	0	0.5	1
den56.4		den56.3		0	0	0.5	1
*compt	/library/tailcomp
tail56.3	den56.2		0.20 0	0	0.10
tail56.2	tail56.3	0.33 0	0	0.10
tail56.1	tail56.2	0.20 0	0	0.10
*compt	/library/headcomp
head56.4	tail56.1	0.20 0	0	0.55
head56.3	head56.4	0.25 0	0	0.55
*compt	/library/head2comp
head56.2	head56.3	0.05 0	0	0.55
*compt	/library/head1comp
head56.1	head56.2	0.05 0	0	0.55
*compt /library/symcompartment
dendr3.57	den56.4		0	0	0.7	1.00
*compt	/library/basecomp
den57.1		dendr3.57	0	0	0.5	1
den57.2		den57.1		0	0	0.5	1
den57.3		den57.2		0	0	0.5	1
den57.4		den57.3		0	0	0.5	1
*compt	/library/tailcomp
tail57.3	den57.2		0.20 0	0	0.10
tail57.2	tail57.3	0.33 0	0	0.10
tail57.1	tail57.2	0.20 0	0	0.10
*compt	/library/headcomp
head57.4	tail57.1	0.20 0	0	0.55
head57.3	head57.4	0.25 0	0	0.55
*compt	/library/head2comp
head57.2	head57.3	0.05 0	0	0.55
*compt	/library/head1comp
head57.1	head57.2	0.05 0	0	0.55
*compt /library/symcompartment
dendr3.58	den57.4		0	0	0.3	1.00
*compt	/library/basecomp
den58.1		dendr3.58	0	0	0.5	1
den58.2		den58.1		0	0	0.5	1
den58.3		den58.2		0	0	0.5	1
den58.4		den58.3		0	0	0.5	1
*compt	/library/tailcomp
tail58.3	den58.2		0.20 0	0	0.10
tail58.2	tail58.3	0.33 0	0	0.10
tail58.1	tail58.2	0.20 0	0	0.10
*compt	/library/headcomp
head58.4	tail58.1	0.20 0	0	0.55
head58.3	head58.4	0.25 0	0	0.55
*compt	/library/head2comp
head58.2	head58.3	0.05 0	0	0.55
*compt	/library/head1comp
head58.1	head58.2	0.05 0	0	0.55
*compt /library/symcompartment
dendr3.59	den58.4		0	0	0.5	1.00
*compt	/library/basecomp
den59.1		dendr3.59	0	0	0.5	1
den59.2		den59.1		0	0	0.5	1
den59.3		den59.2		0	0	0.5	1
den59.4		den59.3		0	0	0.5	1
*compt	/library/tailcomp
tail59.3	den59.2		0.20 0	0	0.10
tail59.2	tail59.3	0.33 0	0	0.10
tail59.1	tail59.2	0.20 0	0	0.10
*compt	/library/headcomp
head59.4	tail59.1	0.20 0	0	0.55
head59.3	head59.4	0.25 0	0	0.55
*compt	/library/head2comp
head59.2	head59.3	0.05 0	0	0.55
*compt	/library/head1comp
head59.1	head59.2	0.05 0	0	0.55
*compt /library/symcompartment
dendr3.60	den59.4		0	0	0.3	1.00

*compt	/library/basecomp
den60.1		dendr3.60	0	0	0.5	1
den60.2		den60.1		0	0	0.5	1
den60.3		den60.2		0	0	0.5	1
den60.4		den60.3		0	0	0.5	1
*compt	/library/tailcomp
tail60.3	den60.2		0.20 0	0	0.10
tail60.2	tail60.3	0.33 0	0	0.10
tail60.1	tail60.2	0.20 0	0	0.10
*compt	/library/headcomp
head60.4	tail60.1	0.20 0	0	0.55
head60.3	head60.4	0.25 0	0	0.55
*compt	/library/head2comp
head60.2	head60.3	0.05 0	0	0.55
*compt	/library/head1comp
head60.1	head60.2	0.05 0	0	0.55
*compt /library/symcompartment
dendr3.61	den60.4		0	0	0.4	1.00
*compt	/library/basecomp
den61.1		dendr3.61	0	0	0.5	1
den61.2		den61.1		0	0	0.5	1
den61.3		den61.2		0	0	0.5	1
den61.4		den61.3		0	0	0.5	1
*compt	/library/tailcomp
tail61.3	den61.2		0.20 0	0	0.10
tail61.2	tail61.3	0.33 0	0	0.10
tail61.1	tail61.2	0.20 0	0	0.10
*compt	/library/headcomp
head61.4	tail61.1	0.20 0	0	0.55
head61.3	head61.4	0.25 0	0	0.55
*compt	/library/head2comp
head61.2	head61.3	0.05 0	0	0.55
*compt	/library/head1comp
head61.1	head61.2	0.05 0	0	0.55
*compt /library/symcompartment
dendr3.62	den61.4		0	0	0.4	1.00
*compt	/library/basecomp
den62.1		dendr3.62	0	0	0.5	1
den62.2		den62.1		0	0	0.5	1
den62.3		den62.2		0	0	0.5	1
den62.4		den62.3		0	0	0.5	1
*compt	/library/tailcomp
tail62.3	den62.2		0.20 0	0	0.10
tail62.2	tail62.3	0.33 0	0	0.10
tail62.1	tail62.2	0.20 0	0	0.10
*compt	/library/headcomp
head62.4	tail62.1	0.20 0	0	0.55
head62.3	head62.4	0.25 0	0	0.55
*compt	/library/head2comp
head62.2	head62.3	0.05 0	0	0.55
*compt	/library/head1comp
head62.1	head62.2	0.05 0	0	0.55
*compt	/library/basecomp
den63.1		den62.4		0	0	0.5	1
den63.2		den63.1		0	0	0.5	1
den63.3		den63.2		0	0	0.5	1
den63.4		den63.3		0	0	0.5	1
*compt	/library/tailcomp
tail63.3	den63.2		0.20 0	0	0.10
tail63.2	tail63.3	0.33 0	0	0.10
tail63.1	tail63.2	0.20 0	0	0.10
*compt	/library/headcomp
head63.4	tail63.1	0.20 0	0	0.55
head63.3	head63.4	0.25 0	0	0.55
*compt	/library/head2comp
head63.2	head63.3	0.05 0	0	0.55
*compt	/library/head1comp
head63.1	head63.2	0.05 0	0	0.55
*compt /library/symcompartment
dendr3.64	den63.4		0	0	0.5	1.00
*compt	/library/basecomp
den64.1		dendr3.64	0	0	0.5	1
den64.2		den64.1		0	0	0.5	1
den64.3		den64.2		0	0	0.5	1
den64.4		den64.3		0	0	0.5	1
*compt	/library/tailcomp
tail64.3	den64.2		0.20 0	0	0.10
tail64.2	tail64.3	0.33 0	0	0.10
tail64.1	tail64.2	0.20 0	0	0.10
*compt	/library/headcomp
head64.4	tail64.1	0.20 0	0	0.55
head64.3	head64.4	0.25 0	0	0.55
*compt	/library/head2comp
head64.2	head64.3	0.05 0	0	0.55
*compt	/library/head1comp
head64.1	head64.2	0.05 0	0	0.55
*compt /library/symcompartment
dendr3.65	den64.4		0	0	0.9	1.00
*compt	/library/basecomp
den65.1		dendr3.65	0	0	0.5	1
den65.2		den65.1		0	0	0.5	1
den65.3		den65.2		0	0	0.5	1
den65.4		den65.3		0	0	0.5	1
*compt	/library/tailcomp
tail65.3	den65.2		0.20 0	0	0.10
tail65.2	tail65.3	0.33 0	0	0.10
tail65.1	tail65.2	0.20 0	0	0.10
*compt	/library/headcomp
head65.4	tail65.1	0.20 0	0	0.55
head65.3	head65.4	0.25 0	0	0.55
*compt	/library/head2comp
head65.2	head65.3	0.05 0	0	0.55
*compt	/library/head1comp
head65.1	head65.2	0.05 0	0	0.55
*compt /library/symcompartment
dendr3.66	den65.4		0	0	0.4	1.00
*compt	/library/basecomp
den66.1		dendr3.66	0	0	0.5	1
den66.2		den66.1		0	0	0.5	1
den66.3		den66.2		0	0	0.5	1
den66.4		den66.3		0	0	0.5	1
*compt	/library/tailcomp
tail66.3	den66.2		0.20 0	0	0.10
tail66.2	tail66.3	0.33 0	0	0.10
tail66.1	tail66.2	0.20 0	0	0.10
*compt	/library/headcomp
head66.4	tail66.1	0.20 0	0	0.55
head66.3	head66.4	0.25 0	0	0.55
*compt	/library/head2comp
head66.2	head66.3	0.05 0	0	0.55
*compt	/library/head1comp
head66.1	head66.2	0.05 0	0	0.55
*compt /library/symcompartment
dendr3.67	den66.4		0	0	0.5	1.00
*compt	/library/basecomp
den67.1		dendr3.67	0	0	0.5	1
den67.2		den67.1		0	0	0.5	1
den67.3		den67.2		0	0	0.5	1
den67.4		den67.3		0	0	0.5	1
*compt	/library/tailcomp
tail67.3	den67.2		0.20 0	0	0.10
tail67.2	tail67.3	0.33 0	0	0.10
tail67.1	tail67.2	0.20 0	0	0.10
*compt	/library/headcomp
head67.4	tail67.1	0.20 0	0	0.55
head67.3	head67.4	0.25 0	0	0.55
*compt	/library/head2comp
head67.2	head67.3	0.05 0	0	0.55
*compt	/library/head1comp
head67.1	head67.2	0.05 0	0	0.55
*compt /library/symcompartment
dendr3.68	den67.4		0	0	0.8	1.00
*compt	/library/basecomp
den68.1		dendr3.68	0	0	0.5	1
den68.2		den68.1		0	0	0.5	1
den68.3		den68.2		0	0	0.5	1
den68.4		den68.3		0	0	0.5	1
*compt	/library/tailcomp
tail68.3	den68.2		0.20 0	0	0.10
tail68.2	tail68.3	0.33 0	0	0.10
tail68.1	tail68.2	0.20 0	0	0.10
*compt	/library/headcomp
head68.4	tail68.1	0.20 0	0	0.55
head68.3	head68.4	0.25 0	0	0.55
*compt	/library/head2comp
head68.2	head68.3	0.05 0	0	0.55
*compt	/library/head1comp
head68.1	head68.2	0.05 0	0	0.55
*compt /library/symcompartment
dendr3.69	den68.4		0	0	0.8	1.00
*compt	/library/basecomp
den69.1		dendr3.69	0	0	0.5	1
den69.2		den69.1		0	0	0.5	1
den69.3		den69.2		0	0	0.5	1
den69.4		den69.3		0	0	0.5	1
*compt	/library/tailcomp
tail69.3	den69.2		0.20 0	0	0.10
tail69.2	tail69.3	0.33 0	0	0.10
tail69.1	tail69.2	0.20 0	0	0.10
*compt	/library/headcomp
head69.4	tail69.1	0.20 0	0	0.55
head69.3	head69.4	0.25 0	0	0.55
*compt	/library/head2comp
head69.2	head69.3	0.05 0	0	0.55
*compt	/library/head1comp
head69.1	head69.2	0.05 0	0	0.55
*compt /library/symcompartment
dendr3.70	den69.4		0	0	0.6	1.00

*compt	/library/basecomp
den70.1		dendr3.70	0	0	0.5	1
den70.2		den70.1		0	0	0.5	1
den70.3		den70.2		0	0	0.5	1
den70.4		den70.3		0	0	0.5	1
*compt	/library/tailcomp
tail70.3	den70.2		0.20 0	0	0.10
tail70.2	tail70.3	0.33 0	0	0.10
tail70.1	tail70.2	0.20 0	0	0.10
*compt	/library/headcomp
head70.4	tail70.1	0.20 0	0	0.55
head70.3	head70.4	0.25 0	0	0.55
*compt	/library/head2comp
head70.2	head70.3	0.05 0	0	0.55
*compt	/library/head1comp
head70.1	head70.2	0.05 0	0	0.55
*compt /library/symcompartment
dendr3.71	den70.4		0	0	0.4	1.00
*compt	/library/basecomp
den71.1		dendr3.71	0	0	0.5	1
den71.2		den71.1		0	0	0.5	1
den71.3		den71.2		0	0	0.5	1
den71.4		den71.3		0	0	0.5	1
*compt	/library/tailcomp
tail71.3	den71.2		0.20 0	0	0.10
tail71.2	tail71.3	0.33 0	0	0.10
tail71.1	tail71.2	0.20 0	0	0.10
*compt	/library/headcomp
head71.4	tail71.1	0.20 0	0	0.55
head71.3	head71.4	0.25 0	0	0.55
*compt	/library/head2comp
head71.2	head71.3	0.05 0	0	0.55
*compt	/library/head1comp
head71.1	head71.2	0.05 0	0	0.55
*compt /library/symcompartment
dendr3.72	den71.4		0	0	0.8	1.00
*compt	/library/basecomp
den72.1		dendr3.72	0	0	0.5	1
den72.2		den72.1		0	0	0.5	1
den72.3		den72.2		0	0	0.5	1
den72.4		den72.3		0	0	0.5	1
*compt	/library/tailcomp
tail72.3	den72.2		0.20 0	0	0.10
tail72.2	tail72.3	0.33 0	0	0.10
tail72.1	tail72.2	0.20 0	0	0.10
*compt	/library/headcomp
head72.4	tail72.1	0.20 0	0	0.55
head72.3	head72.4	0.25 0	0	0.55
*compt	/library/head2comp
head72.2	head72.3	0.05 0	0	0.55
*compt	/library/head1comp
head72.1	head72.2	0.05 0	0	0.55
*compt /library/symcompartment
dendr3.73	den72.4		0	0	0.6	1.00
*compt	/library/basecomp
den73.1		dendr3.73	0	0	0.5	1
den73.2		den73.1		0	0	0.5	1
den73.3		den73.2		0	0	0.5	1
den73.4		den73.3		0	0	0.5	1
*compt	/library/tailcomp
tail73.3	den73.2		0.20 0	0	0.10
tail73.2	tail73.3	0.33 0	0	0.10
tail73.1	tail73.2	0.20 0	0	0.10
*compt	/library/headcomp
head73.4	tail73.1	0.20 0	0	0.55
head73.3	head73.4	0.25 0	0	0.55
*compt	/library/head2comp
head73.2	head73.3	0.05 0	0	0.55
*compt	/library/head1comp
head73.1	head73.2	0.05 0	0	0.55
*compt /library/symcompartment
dendr3.74	den73.4		0	0	0.5	1.00
*compt	/library/basecomp
den74.1		dendr3.74	0	0	0.5	1
den74.2		den74.1		0	0	0.5	1
den74.3		den74.2		0	0	0.5	1
den74.4		den74.3		0	0	0.5	1
*compt	/library/tailcomp
tail74.3	den74.2		0.20 0	0	0.10
tail74.2	tail74.3	0.33 0	0	0.10
tail74.1	tail74.2	0.20 0	0	0.10
*compt	/library/headcomp
head74.4	tail74.1	0.20 0	0	0.55
head74.3	head74.4	0.25 0	0	0.55
*compt	/library/head2comp
head74.2	head74.3	0.05 0	0	0.55
*compt	/library/head1comp
head74.1	head74.2	0.05 0	0	0.55
*compt	/library/basecomp
den75.1		den74.4		0	0	0.5	1
den75.2		den75.1		0	0	0.5	1
den75.3		den75.2		0	0	0.5	1
den75.4		den75.3		0	0	0.5	1
*compt	/library/tailcomp
tail75.3	den75.2		0.20 0	0	0.10
tail75.2	tail75.3	0.33 0	0	0.10
tail75.1	tail75.2	0.20 0	0	0.10
*compt	/library/headcomp
head75.4	tail75.1	0.20 0	0	0.55
head75.3	head75.4	0.25 0	0	0.55
*compt	/library/head2comp
head75.2	head75.3	0.05 0	0	0.55
*compt	/library/head1comp
head75.1	head75.2	0.05 0	0	0.55
*compt /library/symcompartment
dendr3.76	den75.4		0	0	0.4	1.00
*compt	/library/basecomp
den76.1		dendr3.76	0	0	0.5	1
den76.2		den76.1		0	0	0.5	1
den76.3		den76.2		0	0	0.5	1
den76.4		den76.3		0	0	0.5	1
*compt	/library/tailcomp
tail76.3	den76.2		0.20 0	0	0.10
tail76.2	tail76.3	0.33 0	0	0.10
tail76.1	tail76.2	0.20 0	0	0.10
*compt	/library/headcomp
head76.4	tail76.1	0.20 0	0	0.55
head76.3	head76.4	0.25 0	0	0.55
*compt	/library/head2comp
head76.2	head76.3	0.05 0	0	0.55
*compt	/library/head1comp
head76.1	head76.2	0.05 0	0	0.55
*compt /library/symcompartment
dendr3.77	den76.4		0	0	0.6	1.00
*compt	/library/basecomp
den77.1		dendr3.77	0	0	0.5	1
den77.2		den77.1		0	0	0.5	1
den77.3		den77.2		0	0	0.5	1
den77.4		den77.3		0	0	0.5	1
*compt	/library/tailcomp
tail77.3	den77.2		0.20 0	0	0.10
tail77.2	tail77.3	0.33 0	0	0.10
tail77.1	tail77.2	0.20 0	0	0.10
*compt	/library/headcomp
head77.4	tail77.1	0.20 0	0	0.55
head77.3	head77.4	0.25 0	0	0.55
*compt	/library/head2comp
head77.2	head77.3	0.05 0	0	0.55
*compt	/library/head1comp
head77.1	head77.2	0.05 0	0	0.55
*compt /library/symcompartment
dendr3.78	den77.4		0	0	0.6	1.00
*compt	/library/basecomp
den78.1		dendr3.78	0	0	0.5	1
den78.2		den78.1		0	0	0.5	1
den78.3		den78.2		0	0	0.5	1
den78.4		den78.3		0	0	0.5	1
*compt	/library/tailcomp
tail78.3	den78.2		0.20 0	0	0.10
tail78.2	tail78.3	0.33 0	0	0.10
tail78.1	tail78.2	0.20 0	0	0.10
*compt	/library/headcomp
head78.4	tail78.1	0.20 0	0	0.55
head78.3	head78.4	0.25 0	0	0.55
*compt	/library/head2comp
head78.2	head78.3	0.05 0	0	0.55
*compt	/library/head1comp
head78.1	head78.2	0.05 0	0	0.55
*compt /library/symcompartment
dendr3.79	den78.4		0	0	0.3	1.00
*compt	/library/basecomp
den79.1		dendr3.79	0	0	0.5	1
den79.2		den79.1		0	0	0.5	1
den79.3		den79.2		0	0	0.5	1
den79.4		den79.3		0	0	0.5	1
*compt	/library/tailcomp
tail79.3	den79.2		0.20 0	0	0.10
tail79.2	tail79.3	0.33 0	0	0.10
tail79.1	tail79.2	0.20 0	0	0.10
*compt	/library/headcomp
head79.4	tail79.1	0.20 0	0	0.55
head79.3	head79.4	0.25 0	0	0.55
*compt	/library/head2comp
head79.2	head79.3	0.05 0	0	0.55
*compt	/library/head1comp
head79.1	head79.2	0.05 0	0	0.55
*compt /library/symcompartment
dendr3.80	den79.4		0	0	0.3	1.00

*compt	/library/basecomp
den80.1		dendr3.80	0	0	0.5	1
den80.2		den80.1		0	0	0.5	1
den80.3		den80.2		0	0	0.5	1
den80.4		den80.3		0	0	0.5	1
*compt	/library/tailcomp
tail80.3	den80.2		0.20 0	0	0.10
tail80.2	tail80.3	0.33 0	0	0.10
tail80.1	tail80.2	0.20 0	0	0.10
*compt	/library/headcomp
head80.4	tail80.1	0.20 0	0	0.55
head80.3	head80.4	0.25 0	0	0.55
*compt	/library/head2comp
head80.2	head80.3	0.05 0	0	0.55
*compt	/library/head1comp
head80.1	head80.2	0.05 0	0	0.55
*compt /library/symcompartment
dendr3.81	den80.4		0	0	0.6	1.00
*compt	/library/basecomp
den81.1		dendr3.81	0	0	0.5	1
den81.2		den81.1		0	0	0.5	1
den81.3		den81.2		0	0	0.5	1
den81.4		den81.3		0	0	0.5	1
*compt	/library/tailcomp
tail81.3	den81.2		0.20 0	0	0.10
tail81.2	tail81.3	0.33 0	0	0.10
tail81.1	tail81.2	0.20 0	0	0.10
*compt	/library/headcomp
head81.4	tail81.1	0.20 0	0	0.55
head81.3	head81.4	0.25 0	0	0.55
*compt	/library/head2comp
head81.2	head81.3	0.05 0	0	0.55
*compt	/library/head1comp
head81.1	head81.2	0.05 0	0	0.55
*compt	/library/basecomp
den82.1		den81.4		0	0	0.5	1
den82.2		den82.1		0	0	0.5	1
den82.3		den82.2		0	0	0.5	1
den82.4		den82.3		0	0	0.5	1
*compt	/library/tailcomp
tail82.3	den82.2		0.20 0	0	0.10
tail82.2	tail82.3	0.33 0	0	0.10
tail82.1	tail82.2	0.20 0	0	0.10
*compt	/library/headcomp
head82.4	tail82.1	0.20 0	0	0.55
head82.3	head82.4	0.25 0	0	0.55
*compt	/library/head2comp
head82.2	head82.3	0.05 0	0	0.55
*compt	/library/head1comp
head82.1	head82.2	0.05 0	0	0.55
*compt /library/symcompartment
dendr3.83	den82.4		0	0	0.7	1.00
*compt	/library/basecomp
den83.1		dendr3.83	0	0	0.5	1
den83.2		den83.1		0	0	0.5	1
den83.3		den83.2		0	0	0.5	1
den83.4		den83.3		0	0	0.5	1
*compt	/library/tailcomp
tail83.3	den83.2		0.20 0	0	0.10
tail83.2	tail83.3	0.33 0	0	0.10
tail83.1	tail83.2	0.20 0	0	0.10
*compt	/library/headcomp
head83.4	tail83.1	0.20 0	0	0.55
head83.3	head83.4	0.25 0	0	0.55
*compt	/library/head2comp
head83.2	head83.3	0.05 0	0	0.55
*compt	/library/head1comp
head83.1	head83.2	0.05 0	0	0.55
*compt /library/symcompartment
dendr3.84	den83.4		0	0	0.5	1.00
*compt	/library/basecomp
den84.1		dendr3.84	0	0	0.5	1
den84.2		den84.1		0	0	0.5	1
den84.3		den84.2		0	0	0.5	1
den84.4		den84.3		0	0	0.5	1
*compt	/library/tailcomp
tail84.3	den84.2		0.20 0	0	0.10
tail84.2	tail84.3	0.33 0	0	0.10
tail84.1	tail84.2	0.20 0	0	0.10
*compt	/library/headcomp
head84.4	tail84.1	0.20 0	0	0.55
head84.3	head84.4	0.25 0	0	0.55
*compt	/library/head2comp
head84.2	head84.3	0.05 0	0	0.55
*compt	/library/head1comp
head84.1	head84.2	0.05 0	0	0.55
*compt /library/symcompartment
dendr3.85	den84.4		0	0	0.7	1.00
*compt	/library/basecomp
den85.1		dendr3.85	0	0	0.5	1
den85.2		den85.1		0	0	0.5	1
den85.3		den85.2		0	0	0.5	1
den85.4		den85.3		0	0	0.5	1
*compt	/library/tailcomp
tail85.3	den85.2		0.20 0	0	0.10
tail85.2	tail85.3	0.33 0	0	0.10
tail85.1	tail85.2	0.20 0	0	0.10
*compt	/library/headcomp
head85.4	tail85.1	0.20 0	0	0.55
head85.3	head85.4	0.25 0	0	0.55
*compt	/library/head2comp
head85.2	head85.3	0.05 0	0	0.55
*compt	/library/head1comp
head85.1	head85.2	0.05 0	0	0.55
*compt /library/symcompartment
dendr3.86	den85.4		0	0	0.4	1.00
*compt	/library/basecomp
den86.1		dendr3.86	0	0	0.5	1
den86.2		den86.1		0	0	0.5	1
den86.3		den86.2		0	0	0.5	1
den86.4		den86.3		0	0	0.5	1
*compt	/library/tailcomp
tail86.3	den86.2		0.20 0	0	0.10
tail86.2	tail86.3	0.33 0	0	0.10
tail86.1	tail86.2	0.20 0	0	0.10
*compt	/library/headcomp
head86.4	tail86.1	0.20 0	0	0.55
head86.3	head86.4	0.25 0	0	0.55
*compt	/library/head2comp
head86.2	head86.3	0.05 0	0	0.55
*compt	/library/head1comp
head86.1	head86.2	0.05 0	0	0.55
*compt /library/symcompartment
dendr3.87	den86.4		0	0	0.6	1.00
*compt	/library/basecomp
den87.1		dendr3.87	0	0	0.5	1
den87.2		den87.1		0	0	0.5	1
den87.3		den87.2		0	0	0.5	1
den87.4		den87.3		0	0	0.5	1
*compt	/library/tailcomp
tail87.3	den87.2		0.20 0	0	0.10
tail87.2	tail87.3	0.33 0	0	0.10
tail87.1	tail87.2	0.20 0	0	0.10
*compt	/library/headcomp
head87.4	tail87.1	0.20 0	0	0.55
head87.3	head87.4	0.25 0	0	0.55
*compt	/library/head2comp
head87.2	head87.3	0.05 0	0	0.55
*compt	/library/head1comp
head87.1	head87.2	0.05 0	0	0.55
*compt /library/symcompartment
dendr3.88	den87.4		0	0	0.9	1.00
*compt	/library/basecomp
den88.1		dendr3.88	0	0	0.5	1
den88.2		den88.1		0	0	0.5	1
den88.3		den88.2		0	0	0.5	1
den88.4		den88.3		0	0	0.5	1
*compt	/library/tailcomp
tail88.3	den88.2		0.20 0	0	0.10
tail88.2	tail88.3	0.33 0	0	0.10
tail88.1	tail88.2	0.20 0	0	0.10
*compt	/library/headcomp
head88.4	tail88.1	0.20 0	0	0.55
head88.3	head88.4	0.25 0	0	0.55
*compt	/library/head2comp
head88.2	head88.3	0.05 0	0	0.55
*compt	/library/head1comp
head88.1	head88.2	0.05 0	0	0.55
*compt	/library/basecomp
den89.1		den88.4		0	0	0.5	1
den89.2		den89.1		0	0	0.5	1
den89.3		den89.2		0	0	0.5	1
den89.4		den89.3		0	0	0.5	1
*compt	/library/tailcomp
tail89.3	den89.2		0.20 0	0	0.10
tail89.2	tail89.3	0.33 0	0	0.10
tail89.1	tail89.2	0.20 0	0	0.10
*compt	/library/headcomp
head89.4	tail89.1	0.20 0	0	0.55
head89.3	head89.4	0.25 0	0	0.55
*compt	/library/head2comp
head89.2	head89.3	0.05 0	0	0.55
*compt	/library/head1comp
head89.1	head89.2	0.05 0	0	0.55
*compt /library/symcompartment
dendr3.90	den89.4		0	0	0.3	1.00

*compt	/library/basecomp
den90.1		dendr3.90	0	0	0.5	1
den90.2		den90.1		0	0	0.5	1
den90.3		den90.2		0	0	0.5	1
den90.4		den90.3		0	0	0.5	1
*compt	/library/tailcomp
tail90.3	den90.2		0.20 0	0	0.10
tail90.2	tail90.3	0.33 0	0	0.10
tail90.1	tail90.2	0.20 0	0	0.10
*compt	/library/headcomp
head90.4	tail90.1	0.20 0	0	0.55
head90.3	head90.4	0.25 0	0	0.55
*compt	/library/head2comp
head90.2	head90.3	0.05 0	0	0.55
*compt	/library/head1comp
head90.1	head90.2	0.05 0	0	0.55
*compt /library/symcompartment
dendr3.91	den90.4		0	0	0.5	1.00
*compt	/library/basecomp
den91.1		dendr3.91	0	0	0.5	1
den91.2		den91.1		0	0	0.5	1
den91.3		den91.2		0	0	0.5	1
den91.4		den91.3		0	0	0.5	1
*compt	/library/tailcomp
tail91.3	den91.2		0.20 0	0	0.10
tail91.2	tail91.3	0.33 0	0	0.10
tail91.1	tail91.2	0.20 0	0	0.10
*compt	/library/headcomp
head91.4	tail91.1	0.20 0	0	0.55
head91.3	head91.4	0.25 0	0	0.55
*compt	/library/head2comp
head91.2	head91.3	0.05 0	0	0.55
*compt	/library/head1comp
head91.1	head91.2	0.05 0	0	0.55
*compt	/library/basecomp
den92.1		den91.4		0	0	0.5	1
den92.2		den92.1		0	0	0.5	1
den92.3		den92.2		0	0	0.5	1
den92.4		den92.3		0	0	0.5	1
*compt	/library/tailcomp
tail92.3	den92.2		0.20 0	0	0.10
tail92.2	tail92.3	0.33 0	0	0.10
tail92.1	tail92.2	0.20 0	0	0.10
*compt	/library/headcomp
head92.4	tail92.1	0.20 0	0	0.55
head92.3	head92.4	0.25 0	0	0.55
*compt	/library/head2comp
head92.2	head92.3	0.05 0	0	0.55
*compt	/library/head1comp
head92.1	head92.2	0.05 0	0	0.55
*compt /library/symcompartment
dendr3.93	den92.4		0	0	0.6	1.00
*compt	/library/basecomp
den93.1		dendr3.93	0	0	0.5	1
den93.2		den93.1		0	0	0.5	1
den93.3		den93.2		0	0	0.5	1
den93.4		den93.3		0	0	0.5	1
*compt	/library/tailcomp
tail93.3	den93.2		0.20 0	0	0.10
tail93.2	tail93.3	0.33 0	0	0.10
tail93.1	tail93.2	0.20 0	0	0.10
*compt	/library/headcomp
head93.4	tail93.1	0.20 0	0	0.55
head93.3	head93.4	0.25 0	0	0.55
*compt	/library/head2comp
head93.2	head93.3	0.05 0	0	0.55
*compt	/library/head1comp
head93.1	head93.2	0.05 0	0	0.55
*compt /library/symcompartment
dendr3.94	den93.4		0	0	0.4	1.00
*compt	/library/basecomp
den94.1		dendr3.94	0	0	0.5	1
den94.2		den94.1		0	0	0.5	1
den94.3		den94.2		0	0	0.5	1
den94.4		den94.3		0	0	0.5	1
*compt	/library/tailcomp
tail94.3	den94.2		0.20 0	0	0.10
tail94.2	tail94.3	0.33 0	0	0.10
tail94.1	tail94.2	0.20 0	0	0.10
*compt	/library/headcomp
head94.4	tail94.1	0.20 0	0	0.55
head94.3	head94.4	0.25 0	0	0.55
*compt	/library/head2comp
head94.2	head94.3	0.05 0	0	0.55
*compt	/library/head1comp
head94.1	head94.2	0.05 0	0	0.55
*compt /library/symcompartment
dendr3.95	den94.4		0	0	0.7	1.00
*compt	/library/basecomp
den95.1		dendr3.95	0	0	0.5	1
den95.2		den95.1		0	0	0.5	1
den95.3		den95.2		0	0	0.5	1
den95.4		den95.3		0	0	0.5	1
*compt	/library/tailcomp
tail95.3	den95.2		0.20 0	0	0.10
tail95.2	tail95.3	0.33 0	0	0.10
tail95.1	tail95.2	0.20 0	0	0.10
*compt	/library/headcomp
head95.4	tail95.1	0.20 0	0	0.55
head95.3	head95.4	0.25 0	0	0.55
*compt	/library/head2comp
head95.2	head95.3	0.05 0	0	0.55
*compt	/library/head1comp
head95.1	head95.2	0.05 0	0	0.55
*compt	/library/basecomp
den96.1		den95.4		0	0	0.5	1
den96.2		den96.1		0	0	0.5	1
den96.3		den96.2		0	0	0.5	1
den96.4		den96.3		0	0	0.5	1
*compt	/library/tailcomp
tail96.3	den96.2		0.20 0	0	0.10
tail96.2	tail96.3	0.33 0	0	0.10
tail96.1	tail96.2	0.20 0	0	0.10
*compt	/library/headcomp
head96.4	tail96.1	0.20 0	0	0.55
head96.3	head96.4	0.25 0	0	0.55
*compt	/library/head2comp
head96.2	head96.3	0.05 0	0	0.55
*compt	/library/head1comp
head96.1	head96.2	0.05 0	0	0.55
*compt /library/symcompartment
dendr3.97	den96.4		0	0	0.4	1.00
*compt	/library/basecomp
den97.1		dendr3.97	0	0	0.5	1
den97.2		den97.1		0	0	0.5	1
den97.3		den97.2		0	0	0.5	1
den97.4		den97.3		0	0	0.5	1
*compt	/library/tailcomp
tail97.3	den97.2		0.20 0	0	0.10
tail97.2	tail97.3	0.33 0	0	0.10
tail97.1	tail97.2	0.20 0	0	0.10
*compt	/library/headcomp
head97.4	tail97.1	0.20 0	0	0.55
head97.3	head97.4	0.25 0	0	0.55
*compt	/library/head2comp
head97.2	head97.3	0.05 0	0	0.55
*compt	/library/head1comp
head97.1	head97.2	0.05 0	0	0.55
*compt /library/symcompartment
dendr3.98	den97.4		0	0	0.6	1.00
*compt	/library/basecomp
den98.1		dendr3.98	0	0	0.5	1
den98.2		den98.1		0	0	0.5	1
den98.3		den98.2		0	0	0.5	1
den98.4		den98.3		0	0	0.5	1
*compt	/library/tailcomp
tail98.3	den98.2		0.20 0	0	0.10
tail98.2	tail98.3	0.33 0	0	0.10
tail98.1	tail98.2	0.20 0	0	0.10
*compt	/library/headcomp
head98.4	tail98.1	0.20 0	0	0.55
head98.3	head98.4	0.25 0	0	0.55
*compt	/library/head2comp
head98.2	head98.3	0.05 0	0	0.55
*compt	/library/head1comp
head98.1	head98.2	0.05 0	0	0.55
*compt /library/symcompartment
dendr3.99	den98.4		0	0	0.7	1.00
*compt	/library/basecomp
den99.1		dendr3.99	0	0	0.5	1
den99.2		den99.1		0	0	0.5	1
den99.3		den99.2		0	0	0.5	1
den99.4		den99.3		0	0	0.5	1
*compt	/library/tailcomp
tail99.3	den99.2		0.20 0	0	0.10
tail99.2	tail99.3	0.33 0	0	0.10
tail99.1	tail99.2	0.20 0	0	0.10
*compt	/library/headcomp
head99.4	tail99.1	0.20 0	0	0.55
head99.3	head99.4	0.25 0	0	0.55
*compt	/library/head2comp
head99.2	head99.3	0.05 0	0	0.55
*compt	/library/head1comp
head99.1	head99.2	0.05 0	0	0.55
*compt /library/symcompartment
dendr3.100	den99.4		-3	0	30	0.80
dendr3.101	dendr3.100	0	0	100	0.80


